# Nuclia CLI/SDK

This SDK/CLI is designed to provide an easy use cased focus experience with Nuclia API.

There are two developer experiences:

- CLI: by using the cli `nuclia` you can interact with Nuclia via command line
- SDK: Using python you can replicate each command using the same structure

## Getting started

First steps should be:

- [Authentication](AUTH.md)
- [Setting KnowledgeBox or NUA key](DEFAULT.md).

## Use Cases

- [Upload files](UPLOAD.md)
- [Upload url](UPLOAD.md)
- [Upload text](UPLOAD.md)
- [Upload conversation](CONVERSATION.md)
- [Search](SEARCH.md)
- [Extract information from a file](EXTRACT.md)
- Detect Entities
- [Get embedding from text](EXTRACT.md)
- Get answer from a context
